/* $Id: e2_option_bool.h 1955 2009-10-02 04:02:01Z tpgww $

Copyright (C) 2004-2009 tooar <tooar@emelfm2.net>

This file is part of emelFM2.
emelFM2 is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

emelFM2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with emelFM2; see the file GPL. If not, contact the Free Software
Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#ifndef __E2_OPTION_BOOL_H__
#define __E2_OPTION_BOOL_H__

E2_OptionSet *e2_option_bool_register (gchar *name, gchar *group, gchar *desc,
	gchar *tip, gchar *depends, gboolean def, E2_OptionFlags flags);
gboolean e2_option_bool_get (gchar *option);
gboolean e2_option_bool_get_direct (E2_OptionSet *set);
gboolean e2_option_bool_toggle (gchar *option);
gboolean e2_option_bool_toggle_direct (E2_OptionSet *set);
gboolean e2_option_bool_set (gchar *option, gboolean state);
gboolean e2_option_bool_set_direct (E2_OptionSet *set, gboolean value);

#endif //ndef __E2_OPTION_BOOL_H__
